//
//  ViximoActivity.h
//  ViximoMobileTestApp
//
//  Created by Jonathan Klein on 1/12/12.
//  Copyright (c) 2012 None. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "ViximoResource.h"

/**
 * An activity feed item from the Viximo SDK.  Feed items are used to notify users about general app
 * activity such as levelling up, winning battles, etc.
 */

@interface ViximoActivity : ViximoResource {
  NSString*     message;
  NSString*     object_id;
  NSString*     context;
  NSString*     action_name;
  NSString*     icon_url;
  
  NSString*     sender_avatar_url;
  NSString*     sender_id;
  NSString*     sender_name;
}

/**
 * The content of the activity feed item message.
 */
@property (nonatomic, retain) NSString *message;

/**
 * The unique ID for this activity feed item.
 */
@property (nonatomic, retain) NSString *object_id;

/**
 * The ID of the user who sent this activity feed item.
 */
@property (nonatomic, retain) NSString *sender_id;

/**
 * The name of the user who sent this activity feed item.
 */
@property (nonatomic, retain) NSString *sender_name;

/**
 * The avatar URL for user who sent this activity feed item.
 */
@property (nonatomic, retain) NSString *sender_avatar_url;

/**
 * Deprecated.  Use contextDictionary instead.
 */
@property (nonatomic, retain) NSString *context __attribute__ ((deprecated));

/**
 * The optional context data dictionary sent with this message.  This value is used for 
 * passing custom data specific to your game and can be used in any way you'd like. 
 */
@property (nonatomic, readonly) NSDictionary *contextDictionary;

/**
 * The call-to-action string associated with the activity feed item.
 */
@property (nonatomic, retain) NSString *action_name;

/**
 * A URL for the image associated with this activity feed item.
 */
@property (nonatomic, retain) NSString *icon_url;


@end

