//
//  ViximoMessage.h
//  ViximoMobileTestApp
//
//  Created by Jonathan Klein on 1/12/12.
//  Copyright (c) 2012 None. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "ViximoResource.h"

/**
 * A message notification sent from the Viximo SDK.  
 * 
 * See [Viximo sendMessage:users:callback:] for more information on sending messages.
 */

@interface ViximoMessage : ViximoResource {
  NSString*       message;
  NSString*       object_id;
  NSString*       sender_id;
  NSString*       sender_name;
  NSString*       sender_avatar_url;
  NSString*       user_message;
  NSString*       context;
  NSMutableArray* recipient_ids;
  NSString*       action_name;
  NSString*       icon_url;
}

/**
 * The primary text sent with this message.
 */
@property (nonatomic, retain) NSString *message;

/**
 * The unique ID for this message.  If the current user is the creator of this message,
 * the ID can be used later to delete or update it.
 */
@property (nonatomic, retain) NSString *object_id;

/**
 * The ID of the user who sent this message.
 */
@property (nonatomic, retain) NSString *sender_id;

/**
 * The name of the user who sent this message.
 */
@property (nonatomic, retain) NSString *sender_name;

/**
 * The avatar URL for the user who sent this message.
 */
@property (nonatomic, retain) NSString *sender_avatar_url;

/**
 * The custom text (if present) that the sender included when sending this message.
 */
@property (nonatomic, retain) NSString *user_message;

/**
 * Deprecated.  Use contextDictionary instead.
 */
@property (nonatomic, retain) NSString *context __attribute__ ((deprecated));

/**
 * The optional context data dictionary sent with this message.  This value is used for 
 * passing custom data specific to your game and can be used in any way you'd like. 
 */
@property (nonatomic, readonly) NSDictionary *contextDictionary;

/**
 * The IDs of all the recipients who should receive this message
 */
@property (nonatomic, retain) NSArray *recipient_ids;

/**
 * The call-to-action string associated with this message.
 */
@property (nonatomic, retain) NSString *action_name;

/**
 * A URL for the image associated with this message.
 */
@property (nonatomic, retain) NSString *icon_url;

@end

