//
//  ViximoUser.h
//  ViximoMobileTestApp
//
//  Created by Jonathan Klein on 1/12/12.
//  Copyright (c) 2012 None. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "ViximoResource.h"

/**
 * A user in the Viximo Mobile SDK.
 */

@interface ViximoUser : ViximoResource {
  NSString*     name;
  NSString*     object_id;
  NSString*     avatar_url;
  NSString*     context;

  NSArray*      relationships;
  BOOL          is_online;
  BOOL          is_game_player;
  BOOL          has_unread_messages;
  NSArray*      groups;
}

/**
 * The unique ID for the user in the Viximo Mobile SDK.
 */
@property (nonatomic, retain) NSString *object_id;

/**
 * The name of this user.
 */
@property (nonatomic, retain) NSString *name;

/**
 * A list of relationships this user is in with the current player.  Only set on friend users, not the current player.
 */
@property (nonatomic, retain) NSArray *relationships;

/**
 * The avatar URL for this user.
 */
@property (nonatomic, retain) NSString *avatar_url;

/**
 * Indicates whether or not this user is online (set on friend users only)
 */
@property (nonatomic, assign) BOOL is_online;

/**
 * Indicates whether or not this user is a player of the current game (set on friend users only).
 */
@property (nonatomic, assign) BOOL is_game_player;

/**
 * Indicates whether or not this user has unread messages
 */
@property (nonatomic, assign) BOOL has_unread_messages;

/**
 * A dictionary of custom data associated with the user.
 * <p>
 * This optional data dictionary is used to convey app specific context that can be retrieved 
 * from the current user or their friends.  This is useful for storing custom IDs or app specific
 * data associated with users such as nickname, level, etc. 
 * <p>
 * The data dictionary for the current user can be set with [Viximo saveUserContextDictionary:callback:].
 */
@property (nonatomic, readonly) NSDictionary *contextDictionary;

/**
 * A list of groups this user is in with the current player.  
 */
@property (nonatomic, retain) NSArray *groups;

@end

