//
//  ViximoActivityData.h
//  ViximoMobileTestApp
//
//  Created by Jonathan Klein on 2/3/12.
//  Copyright (c) 2012 None. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "ViximoResource.h"

/**
 * A class used to construct an activity feed item to be sent to a set of users.
 * <p>
 * The constructor takes the required parameters of message text, icon and action name.  
 * The optional setContextData allows you to add a game-specific context string which you can use 
 * for custom handling when the activity is received. 
 */
@interface ViximoActivityData : ViximoResource {
  NSString*   context;
  NSString*   actionName;
  NSString*   message;
  NSURL*      iconURL;
}

/**
 * This value is deprecated.  Use contextDictionary instead.
 */
@property (nonatomic,retain) NSString*  context __attribute__ ((deprecated));

/** 
 * The text message content of this activity item. 
 */
@property (nonatomic,retain) NSString*  message;

/** 
 * A short call-to-action string to be displayed to the user with the feed item.  Must be 10 characters or less. 
 */
@property (nonatomic,retain) NSString*  actionName;

/**
 * The URL of the icon to be displayed with the activity item.  The URL should reference a 90x90 square PNG or JPG image that you host on your own server.
 */
@property (nonatomic,retain) NSURL*     iconURL;

/**
 * Specifies a custom user context dictionary.
 * <p>
 * The optional user context dictionary is used to convey app specific context that can be retrieved 
 * when the message is received.  In order to ensure efficient delivery of context data in messages, the dictionary 
 * is subject to the following limitations:
 * - there may be at most 5 keys
 * - all keys and values must be NSString objects
 * - keys may be at most 64 characters
 * - values may be at most 256 characters
 * - using the key report_category will allow you to breakdown conversions for different categories in the reports
 */
@property (nonatomic,retain) NSDictionary*       contextDictionary;

/** 
 * Creates an instance of ViximoActivityData with the provided data.
 * @param message     The text message content of this activity item.
 * @param iconURL     The URL of the icon to be displayed with the activity item.
 * @param actionName  A short call-to-action string to be displayed to the user with the feed item.  Must be 10 characters or less.
 */
+ (ViximoActivityData*)dataWithMessage:(NSString*)message iconURL:(NSURL*)iconURL actionName:(NSString*)actionName;


@end
