//
//  ViximoDelegate.h
//  ViximoMobileTestApp
//
//  Created by Jonathan Klein on 1/13/12.
//  Copyright (c) 2012 None. All rights reserved.
//

#import <UIKit/UIKit.h>

#import "ViximoApp.h"
#import "ViximoUser.h"
#import "ViximoMessage.h"
#import "ViximoActivity.h"

/**
 * A protocol defining callbacks made from the Viximo Mobile SDK back into your app.
 */

@protocol ViximoDelegate<NSObject>

@optional

/**
 * A callback invoked upon successful initialization.
 * @param app The app object which was initialized.
 */
- (void)onInitialize:(ViximoApp*)app;

/**
 * A callback invoked when a friend's presence change is detected.
 * @param user The friend user whose presence has changed.
 */
- (void)onUserPresenceChanged:(ViximoUser*)user;

/**
 * A callback invoked when a notification message is received. 
 * @param message The message that was received.
 */
- (void)onMessageReceived:(ViximoMessage*)message;

/**
 * A callback invoked when a notification message call to action is completed.
 * @param message The message that was acted upon.
 */
- (void)onMessageAction:(ViximoMessage*)message;

/**
 * A callback invoked when a news feed item is received. 
 * @param activity The activity that was received.
 */
- (void)onActivityReceived:(ViximoActivity*)activity;

/**
 * A callback invoked when a news feed item call to action is completed. 
 * @param activity The activity that was acted upon.
 */
- (void)onActivityAction:(ViximoActivity*)activity;

/**
 * A callback invoked when the Viximo UI is about to display.  You should implement
 * this method to disable any rendering or other computationally expensive operations
 * in order to assure the best possible experience for users while the Viximo UI is displayed. 
 */
- (void)viximoUIWillDisplay;

/**
 * A callback invoked when the Viximo UI is done displaying.  You should implement
 * this method to resume any rendering or other operations that were suspended in viximoUIWillDisplay.
 */
- (void)viximoUIDidHide;

/**
 * An optional method to specify which orientations the Viximo SDK interface should be allowed to 
 * rotate to.  This method works in the same manner as UIViewController's shouldAutorotateToInterfaceOrientation:.
 * If not specified, the UI will render in portrait mode only.
 * @param orientation The orientation being inquired about.
 */
- (BOOL)viximoShouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)orientation;

@end
