//
//  ViximoInviteData.h
//  ViximoMobileTestApp
//
//  Created by Jonathan Klein on 2/3/12.
//  Copyright (c) 2012 None. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "ViximoActivityData.h"

/**
 * A class for constructing the contents of an invite
 * <p>
 * When sending a message to other users, you use this class to specify the content of the message.
 * The constructor takes the required parameters for the messageText, icon and actionName.  
 * Optionally setting the contextDictionary property will allow you to pass app-specific content which
 * can be retreived when the invite is received.
 */
@interface ViximoInviteData : ViximoActivityData {
  NSString*   dialogTitle;
  NSString*   dialogDescription;
}

/** 
 * The title to display in the UI dialog for selecting friends to invite.
 * "Invite Friends" will be the default.
 */
@property (nonatomic,retain) NSString*  dialogTitle;

/**
 * The call-to-action description to display in the UI dialog. This will be displayed under the dialog title.
 * "Invite your friends to play with you!" will be the default.
 */
@property (nonatomic,retain) NSString*  dialogDescription;

/** 
 * Creates an instance of ViximoInviteData with the provided data.
 * @param message     The text message content of this invite.
 * @param iconURL     The URL of the icon to be displayed with the invite.
 * @param actionName  A short call-to-action string to be displayed to the user with the invite.  Must be 10 characters or less.
 */
+ (ViximoInviteData*)dataWithMessage:(NSString*)message iconURL:(NSURL*)iconURL actionName:(NSString*)actionName;

/**
 * Returns an autoreleased ViximoInviteData.
 */
+ (ViximoInviteData*)inviteData;

@end
