//
//  ViximoMessageData.h
//  ViximoMobileTestApp
//
//  Created by Jonathan Klein on 2/3/12.
//  Copyright (c) 2012 None. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "ViximoActivityData.h"

/**
 * A class for constructing a notification message to be sent to a set of users.
 * <p>
 * When sending a message to other users, you use this class to specify the content of the message.
 * The constructor takes the required parameters for the messageText, icon and actionName.  
 * Other methods set optional values such as a delivery date (deliverAt); whether or not the 
 * message should appear as being sent from the game (isFromUser); as well as game-specific context
 * data ([ViximoActivityData context]).
 */
@interface ViximoMessageData : ViximoActivityData {
  BOOL            isFromUser;
  BOOL            transient;
  BOOL            allowsCustomMessage;
  NSDate*         deliverAt;
}

/**
 * An optional future delivery data for this message.
 * <p>
 * If this value is set to a date in the future, the notification will be delivered at the specified time.
 * When this value is null (the default state) the message will be delivered immediately.
 * <p>
 * This functionality is typically used to create an appointment gaming dynamic in which users are
 * brought back into the game at a future time when an action completes.
 */
@property (nonatomic,retain) NSDate*    deliverAt;


/**
 * Specifies whether the message should appear to have been sent by the current user, or by the game itself.
 * <p>
 * When this value is set, the message is presented as though it was sent by the current user.  When set to false,
 * the message appears to have been sent from the game.  The default value is true.
 */
@property (nonatomic,assign) BOOL       isFromUser;


/**
 * Specifies whether the message should be transient.
 * <p>
 * Transient messages are delivered as notifications only.  They are delivered only by Push, will not appear 
 * in the message center or unread message lists, and cannot be marked as read or deleted.  You app may still receive 
 * and consume transient messages through [ViximoDelegate onActivityReceived:], however.
 */
@property (nonatomic,assign) BOOL       transient;


/**
 * Specifies whether the user should be allowed to enter a custom message or not.
 * <p>
 * When set to true, the user will be presented with a dialog allowing them to write a custom message
 * to accompany this notification.  The default value is false.
 */
@property (nonatomic,assign) BOOL       allowsCustomMessage;

+ (ViximoMessageData*)dataWithMessage:(NSString*)message iconURL:(NSURL*)iconURL actionName:(NSString*)actionName;

@end
