//
//  ViximoShareData.h
//  ViximoMobileTestApp
//
//  Created by Jonathan Klein on 2/3/12.
//  Copyright (c) 2012 None. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h> //Needed for UIImage
#import "ViximoResource.h"

typedef enum {
    ViximoNetworkNone = 0,
    ViximoNetworkFacebook,
    ViximoNetworkTwitter,
    ViximoNetworkAny
    
} ViximoNetwork;


/**
 * A class used to construct content to be shared to a 3rd-party network.
 * <p>
 * The constructor takes the required parameters of message text.
 * Other methods set optional values such as a image url; where to link
 * users to when they click on the shared post; as well as which network
 * to target.
 */
@interface ViximoShareData: ViximoResource {
  ViximoNetwork   network;
  NSString*   message;
  NSURL*      linkURL;
  NSURL*      imageURL;
  NSString*   linkName;
  NSString*   linkCaption;

  UIImage*    imageData;
}

/**
 * Specifies the network to share this content to.
 * <p>
 * If this value is set to ViximoNetworkAny then Viximo will either choose
 * the network that a user is connected to or a list of options to choose from.
 */
@property (nonatomic) ViximoNetwork network;

/**
 * Sets the main text of the post being shared.  This is the only required
 * parameter for sharing to a network.
 */
@property (nonatomic,retain) NSString*  message;

/**
 * Sets the url to link the shared post to.
 * <p>
 * When not specified, the shared post will link to a landing page for your
 * application hosted on the Social Zone website.
 */
@property (nonatomic,retain) NSURL*     linkURL;

/**
 * Sets the url of the image to be displayed alongside fo the shared post.
 * <p>
 * When not specified, the icon for your application will be used.
 */
@property (nonatomic,retain) NSURL*     imageURL;

/**
 * Sets text to display for the link being included in the shared post
 * <p>
 * This name behaves as a short title for the shared content and will be link
 * to the link url configured for this share data.  If not specified, the name
 * of the application will be used.
 */
@property (nonatomic,retain) NSString*  linkName;

/**
 * Sets a brief summary message to display as a preview for the full message
 * in the shared post.
 * <p>
 * If not specified, a call-to-action (such as "Join me in <Game name here>!"
 * will be displayed.
 */
@property (nonatomic,retain) NSString*  linkCaption;

/**
 * Sets the data of the image to be displayed alongside fo the shared post.
 * <p>
 * When not specified, the icon for your application will be used.
 */
@property (nonatomic,retain) UIImage*   imageData;

/** 
 * Creates an instance of ViximoShareData with the provided data.
 * @param message     The main text portion of the content describing the shared post.
 */
+ (ViximoShareData*)dataWithMessage:(NSString*)message;

@end
